@@ -64,6 +64,7 @@ static GdmDisplay *d;
 static gchar *login = NULL;
 static sigset_t mask;
 static gboolean greet = FALSE;
+static gboolean remanage_asap = FALSE;
 static gboolean do_timed_login = FALSE; /* if this is true,
 					   login the timed login */
 static gboolean do_configurator = FALSE; /* if this is true, login as root
@@ -91,6 +92,7 @@ extern gboolean GdmConfigAvailable;
 extern gboolean GdmSystemMenu;
 extern gint GdmXineramaScreen;
 extern gchar *GdmGreeter;
+extern gchar *GdmRemoteGreeter;
 extern gchar *GdmChooser;
 extern gchar *GdmDisplayInit;
 extern gchar *GdmPreSession;
@@ -110,7 +112,7 @@ extern gboolean GdmKillInitClients;
 extern gint GdmPingInterval;
 extern gint GdmRetryDelay;
 extern gboolean GdmAllowRoot;
-extern sigset_t sysmask;
+extern gboolean GdmAllowRemoteRoot;
 extern gchar *GdmGlobalFaceDir;
 extern gboolean GdmBrowser;
 extern gboolean GdmDebug;
@@ -367,14 +369,14 @@ gdm_slave_run (GdmDisplay *display)
 		     * that we've given up.  The error is likely something
 		     * internal. */
 		    gdm_text_message_dialog
-			    (_("I could not start the X\n"
-			       "server (your graphical environment)\n"
-			       "due to some internal error.\n"
-			       "Please contact your system administrator\n"
-			       "or check your syslog to diagnose.\n"
-			       "In the meantime this display will be\n"
-			       "disabled.  Please restart gdm when\n"
-			       "the problem is corrected."));
+			    (gdm_cons_i18n (N_("I could not start the X\n"
+					       "server (your graphical environment)\n"
+					       "due to some internal error.\n"
+					       "Please contact your system administrator\n"
+					       "or check your syslog to diagnose.\n"
+					       "In the meantime this display will be\n"
+					       "disabled.  Please restart gdm when\n"
+					       "the problem is corrected.")));
 		    _exit (DISPLAY_ABORT);
 	    }
 	    gdm_slave_send_num (GDM_SOP_XPID, d->servpid);
@@ -474,6 +476,7 @@ gdm_slave_run (GdmDisplay *display)
 	       strcmp (ParsedAutomaticLogin, "root") != 0) {
 	    gdm_first_login = FALSE;
 
+	    d->logged_in = TRUE;
 	    gdm_slave_send_num (GDM_SOP_LOGGED_IN, TRUE);
 	    gdm_slave_send_string (GDM_SOP_LOGIN, ParsedAutomaticLogin);
 
@@ -482,9 +485,13 @@ gdm_slave_run (GdmDisplay *display)
 	    }
 
 	    gdm_slave_send_num (GDM_SOP_LOGGED_IN, FALSE);
+	    d->logged_in = FALSE;
 	    gdm_slave_send_string (GDM_SOP_LOGIN, "");
 
 	    gdm_debug ("gdm_slave_run: Automatic login done");
+	    
+	    if (remanage_asap)
+		    _exit (DISPLAY_REMANAGE);
     } else {
 	    if (gdm_first_login)
 		    gdm_first_login = FALSE;
@@ -493,6 +500,7 @@ gdm_slave_run (GdmDisplay *display)
 	    do {
 		    gdm_slave_wait_for_login (); /* wait for a password */
 
+		    d->logged_in = TRUE;
 		    gdm_slave_send_num (GDM_SOP_LOGGED_IN, TRUE);
 
 		    if (do_timed_login) {
@@ -509,8 +517,12 @@ gdm_slave_run (GdmDisplay *display)
 		    }
 
 		    gdm_slave_send_num (GDM_SOP_LOGGED_IN, FALSE);
+		    d->logged_in = FALSE;
 		    gdm_slave_send_string (GDM_SOP_LOGIN, "");
 
+		    if (remanage_asap)
+			    _exit (DISPLAY_REMANAGE);
+
 		    if (greet) {
 			    gdm_slave_greeter_ctl_no_ret (GDM_ENABLE, "");
 			    gdm_slave_greeter_ctl_no_ret (GDM_RESETOK, "");
@@ -798,6 +810,7 @@ gdm_slave_wait_for_login (void)
 				continue;
 			}
 
+			d->logged_in = TRUE;
 			gdm_slave_send_num (GDM_SOP_LOGGED_IN, TRUE);
 			/* Note: nobody really logged in */
 			gdm_slave_send_string (GDM_SOP_LOGIN, "");
@@ -814,6 +827,10 @@ gdm_slave_wait_for_login (void)
 			gdm_verify_cleanup (d);
 
 			gdm_slave_send_num (GDM_SOP_LOGGED_IN, FALSE);
+			d->logged_in = FALSE;
+
+			if (remanage_asap)
+				_exit (DISPLAY_REMANAGE);
 
 			gdm_slave_greeter_ctl_no_ret (GDM_ENABLE, "");
 			gdm_slave_greeter_ctl_no_ret (GDM_RESETOK, "");
@@ -1087,7 +1104,8 @@ gdm_slave_greeter (void)
 
     /* Open a pipe for greeter communications */
     if (pipe (pipe1) < 0 || pipe (pipe2) < 0) 
-	gdm_slave_exit (DISPLAY_ABORT, _("gdm_slave_greeter: Can't init pipe to gdmgreeter"));
+	gdm_slave_exit (DISPLAY_ABORT, _("%s: Can't init pipe to gdmgreeter"),
+			"gdm_slave_greeter");
     
     /* Fork. Parent is gdmslave, child is greeter process. */
     gdm_sigchld_block_push ();
@@ -1195,7 +1213,7 @@ gdm_slave_greeter (void)
 		gdm_error_box (d,
 			       GTK_MESSAGE_ERROR,
 			       _("No servers were defined in the\n"
-				 "configuration file and xdmcp was\n"
+				 "configuration file and XDMCP was\n"
 				 "disabled.  This can only be a\n"
 				 "configuration error.  So I have started\n"
 				 "a single server for you.  You should\n"
@@ -1224,17 +1242,20 @@ gdm_slave_greeter (void)
 		g_free (msg);
 	}
 
-	argv = ve_split (GdmGreeter);
+	if (d->console)
+		argv = ve_split (GdmGreeter);
+	else
+		argv = ve_split (GdmRemoteGreeter);
 	execv (argv[0], argv);
 
 	gdm_error (_("gdm_slave_greeter: Cannot start greeter trying default: %s"),
-		   EXPANDED_BINDIR
-		   "/gdmlogin --disable-sound --disable-crash-dialog");
+		   EXPANDED_BINDIR "/gdmlogin");
 
 	gnome_setenv ("GDM_WHACKED_GREETER_CONFIG", "true", TRUE);
 
-	argv = ve_split (EXPANDED_BINDIR
-			 "/gdmlogin --disable-sound --disable-crash-dialog");
+	argv = g_new0 (char *, 2);
+	argv[0] = EXPANDED_BINDIR "/gdmlogin";
+	argv[1] = NULL;
 	execv (argv[0], argv);
 
 	gdm_error_box (d,
@@ -1245,10 +1266,10 @@ gdm_slave_greeter (void)
 			 "Try logging in by other means and\n"
 			 "editing the configuration file"));
 	
-	gdm_child_exit (DISPLAY_ABORT, _("gdm_slave_greeter: Error starting greeter on display %s"), d->name);
+	gdm_child_exit (DISPLAY_ABORT, _("%s: Error starting greeter on display %s"), "gdm_slave_greeter", d->name);
 	
     case -1:
-	gdm_slave_exit (DISPLAY_ABORT, _("gdm_slave_greeter: Can't fork gdmgreeter process"));
+	gdm_slave_exit (DISPLAY_ABORT, _("%s: Can't fork gdmgreeter process"), "gdm_slave_greeter");
 	
     default:
 	close (pipe1[0]);
@@ -1292,7 +1313,6 @@ parent_exists (void)
 void
 gdm_slave_send (const char *str, gboolean wait_for_usr2)
 {
-	char *msg;
 	int fd;
 	char *fifopath;
 	int i;
@@ -1312,11 +1332,7 @@ gdm_slave_send (const char *str, gboolean wait_for_usr2)
 		return;
 	}
 
-	msg = g_strdup_printf ("\n%s\n", str);
-
-	write (fd, msg, strlen (msg));
-
-	g_free (msg);
+	gdm_fdprintf (fd, "\n%s\n", str);
 
 	close (fd);
 
@@ -1378,7 +1394,6 @@ gdm_slave_send_string (const char *opcode, const char *str)
 static void
 send_chosen_host (GdmDisplay *disp, const char *hostname)
 {
-	char *msg;
 	int fd;
 	char *fifopath;
 	struct hostent *host;
@@ -1405,13 +1420,9 @@ send_chosen_host (GdmDisplay *disp, const char *hostname)
 		return;
 	}
 
-	msg = g_strdup_printf ("\n%s %d %s\n", GDM_SOP_CHOSEN,
-			       disp->indirect_id,
-			       inet_ntoa (*((struct in_addr *)host->h_addr_list[0])));
-
-	write (fd, msg, strlen (msg));
-
-	g_free (msg);
+	gdm_fdprintf (fd, "\n%s %d %s\n", GDM_SOP_CHOSEN,
+		      disp->indirect_id,
+		      inet_ntoa (*((struct in_addr *)host->h_addr_list[0])));
 
 	close (fd);
 }
@@ -1837,6 +1848,7 @@ session_child_run (struct passwd *pwent,
 		   gboolean sessoptok,
 		   gboolean savegnomesess)
 {
+	sigset_t mask; 
 	int i;
 	char *sesspath, *sessexec;
 	gboolean need_config_sync = FALSE;
@@ -1939,8 +1951,15 @@ session_child_run (struct passwd *pwent,
 	open ("/dev/null", O_RDWR); /* open stdout - fd 1 */
 	open ("/dev/null", O_RDWR); /* open stderr - fd 2 */
 	
-	/* Restore sigmask inherited from init */
-	sigprocmask (SIG_SETMASK, &sysmask, NULL);
+	sigemptyset (&mask);
+	sigprocmask (SIG_SETMASK, &mask, NULL);
+
+	signal (SIGCHLD, SIG_DFL);
+	signal (SIGTERM, SIG_DFL);
+	signal (SIGPIPE, SIG_DFL);
+	signal (SIGALRM, SIG_DFL);
+	signal (SIGHUP, SIG_DFL);
+
 
 	/* If "Gnome Chooser" is still set as a session,
 	 * just change that to "Gnome", since "Gnome Chooser" is a
@@ -2983,4 +3002,39 @@ gdm_parse_enriched_login (const gchar *s, GdmDisplay *display)
     return buffer;
 }
 
+void
+gdm_slave_handle_notify (GdmConnection *conn, const char *msg, gpointer data)
+{
+	GdmDisplay *display = data;
+	int val;
+
+	if (sscanf (msg, GDM_NOTIFY_ALLOWROOT " %d", &val) == 1) {
+		GdmAllowRoot = val;
+	} else if (sscanf (msg, GDM_NOTIFY_ALLOWREMOTEROOT " %d", &val) == 1) {
+		GdmAllowRemoteRoot = val;
+	} else if (sscanf (msg, GDM_NOTIFY_ALLOWREMOTEAUTOLOGIN " %d", &val) == 1) {
+		GdmAllowRemoteAutoLogin = val;
+	} else if (sscanf (msg, GDM_NOTIFY_RETRYDELAY " %d", &val) == 1) {
+		GdmRetryDelay = val;
+	} else if (strncmp (msg, GDM_NOTIFY_GREETER " ",
+			    strlen (GDM_NOTIFY_GREETER) + 1) == 0) {
+		/* FIXME: can't handle flexi servers without going all cranky */
+		if (display->type == TYPE_LOCAL) {
+			if ( ! display->logged_in)
+				_exit (DISPLAY_REMANAGE);
+			else
+				remanage_asap = TRUE;
+		}
+	} else if (strncmp (msg, GDM_NOTIFY_REMOTEGREETER " ",
+			    strlen (GDM_NOTIFY_REMOTEGREETER) + 1) == 0) {
+		/* FIXME: can't handle flexi servers without going all cranky */
+		if (display->type == TYPE_XDMCP) {
+			if ( ! display->logged_in)
+				_exit (DISPLAY_REMANAGE);
+			else
+				remanage_asap = TRUE;
+		}
+	}
+}
+
 /* EOF */
