@@ -431,7 +431,8 @@ gdm_verify_user (GdmDisplay *d,
     if ( ! error_msg_given &&
 	gdm_slave_should_complain ()) {
 	    /* I'm not sure yet if I should display this message for any other issues - heeten */
-	    if (pamerr == PAM_AUTH_ERR) {
+	    if (pamerr == PAM_AUTH_ERR ||
+		pamerr == PAM_USER_UNKNOWN) {
 		    /* FIXME: Hmm, how are we sure that the login is username
 		     * and password.  That is the most common case but not
 		     * neccessairly true, this message needs to be changed
@@ -519,7 +520,7 @@ gdm_verify_setup_user (GdmDisplay *d, const gchar *login, const gchar *display)
 	    gdm_error_box (cur_gdm_disp,
 			   GTK_MESSAGE_ERROR,
 		    _("\nThe change of the authentication token failed. "
-		      "Please try again later or cantact the system administrator."));
+		      "Please try again later or contact the system administrator."));
 	    goto setup_pamerr;
 	}
 	*/
@@ -534,7 +535,7 @@ gdm_verify_setup_user (GdmDisplay *d, const gchar *login, const gchar *display)
 	gdm_error (_("User %s not permitted to gain access at this time"), login);
 	gdm_error_box (cur_gdm_disp,
 		       GTK_MESSAGE_ERROR,
-		       _("\nThe system administrator has your disabled access to the system temporary."));
+		       _("\nThe system administrator has disabled your access to the system temporary."));
 	goto setup_pamerr;
     default :
 	if (gdm_slave_should_complain ())
@@ -645,22 +646,23 @@ gdm_verify_cleanup (GdmDisplay *d)
 void
 gdm_verify_check (void)
 {
-	/* FIXME: this is somewhat evil */
-	if (access (PAM_PREFIX "/pam.d/gdm", F_OK) != 0 &&
-	    access ("/etc/pam.d/gdm", F_OK) != 0 &&
-	    access (PAM_PREFIX "/pam.conf", F_OK) != 0 &&
-	    access ("/etc/pam.conf", F_OK) != 0) {
-		char *s;
-		s = g_strdup_printf (_("Can't find PAM configuration file for gdm. "
-				       "I've tried %s, %s, %s and %s"),
-				     PAM_PREFIX "/pam.d/gdm",
-				     "/etc/pam.d/gdm",
-				     PAM_PREFIX "/pam.conf",
-				     "/etc/pam.conf");
-		gdm_text_message_dialog (s);
-		gdm_fail ("gdm_verify_check: %s", s);
-		g_free (s); /* I'm an anal wanker */
+	pam_handle_t *ph = NULL;
+
+	if (pam_start ("gdm", NULL, &standalone_pamc, &ph) != PAM_SUCCESS) {
+		closelog ();
+		openlog ("gdm", LOG_PID, LOG_DAEMON);
+
+		gdm_text_message_dialog
+			(gdm_cons_i18n (N_("Can't find PAM configuration for gdm.")));
+		gdm_fail ("gdm_verify_check: %s",
+			  _("Can't find PAM configuration for gdm."));
 	}
+
+	if (ph != NULL)
+		pam_end (ph, PAM_SUCCESS);
+
+	closelog ();
+	openlog ("gdm", LOG_PID, LOG_DAEMON);
 }
 
 /* used in pam */
