@@ -18,7 +18,8 @@
  * 
  */
 
-#include <gnome.h>
+#include <libgnome/libgnome.h>
+#include <libgnomeui/libgnomeui.h>
 #include <glade/glade.h>
 #include <ctype.h>
 #include <unistd.h>
@@ -55,6 +56,13 @@ struct _GdmConfigSession {
                               (char *)value); \
            g_free(value); \
         }
+#define gdm_file_entry_set(entry_name, value) \
+        if (value != NULL) { \
+		gnome_file_entry_set_filename \
+			(GNOME_FILE_ENTRY (get_widget(entry_name)), \
+			 (char *)value); \
+		g_free(value); \
+        }
 #define gdm_radio_set(radio_name, value, maximum) \
         if (value >= 0 && value <= maximum) { \
 	   gchar *widget_name = g_strdup_printf ("%s_%d", radio_name, value); \
@@ -75,10 +83,6 @@ struct _GdmConfigSession {
            gnome_icon_entry_set_icon(GNOME_ICON_ENTRY(get_widget(icon_name)), \
                               (char *)value);
 
-#define gdm_font_set(font_name, value) \
-        if (value) \
-           gnome_font_picker_set_font_name(GNOME_FONT_PICKER(get_widget(font_name)), \
-                                           (char *)value);
 #define gdm_color_set(picker_name, value) \
         if (value) { \
 	   GdkColor color; \
@@ -92,6 +96,12 @@ struct _GdmConfigSession {
 
 #define gdm_entry_write(entry_name, key) \
         gnome_config_set_string(key, gtk_entry_get_text(GTK_ENTRY(get_widget(entry_name))));
+#define gdm_file_entry_write(entry_name, key) { \
+	char * path = gnome_file_entry_get_full_path \
+		(GNOME_FILE_ENTRY (get_widget (entry_name)), FALSE); \
+	gnome_config_set_string (key, path); \
+	g_free (path); \
+}
 
 #define gdm_spin_write(spin_button_name, key) \
         gnome_config_set_int(key, gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(get_widget(spin_button_name))));
@@ -105,7 +115,7 @@ struct _GdmConfigSession {
 
 #define gdm_icon_write(icon_name, key) \
 	{ \
-	char *icon = hack_icon_entry_get_icon(GNOME_ICON_ENTRY(get_widget(icon_name))); \
+	char *icon = gnome_icon_entry_get_filename(GNOME_ICON_ENTRY(get_widget(icon_name))); \
         if (icon != NULL) \
            gnome_config_set_string(key, icon); \
         else \
@@ -113,9 +123,6 @@ struct _GdmConfigSession {
 	g_free (icon); \
 	}
 
-#define gdm_font_write(picker_name, key) \
-        gnome_config_set_string(key, gnome_font_picker_get_font_name(GNOME_FONT_PICKER(get_widget(picker_name))));
-
 #define gdm_color_write(picker_name, key) \
 	{ \
 		char *value; \
