@@ -19,7 +19,8 @@
  */
 
 #include "config.h"
-#include <gnome.h>
+#include <libgnome/libgnome.h>
+#include <libgnomeui/libgnomeui.h>
 #include <gdk/gdkx.h>
 #include <X11/Xauth.h>
 
@@ -196,7 +197,7 @@ get_display (void)
 	static char *display = NULL;
 
 	if (display == NULL) {
-		display = g_strdup (gdk_display_name);
+		display = g_strdup (gdk_get_display ());
 		if (display == NULL) {
 			display = g_strdup (g_getenv ("DISPLAY"));
 			if (display == NULL) /*eek!*/ {
@@ -521,8 +522,9 @@ main (int argc, char *argv[])
 	poptContext ctx;
 	const char **args;
 
-	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
-	textdomain (PACKAGE);
+	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
 
 	gnome_init_with_popt_table ("gdmflexiserver", VERSION, argc, argv,
 				    options, 0, &ctx);
